==> opensaml-xmlsec-impl-4.3.2-sources.jar: org/opensaml/xmlsec/encryption/impl/SaltBuilder.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.xmlsec.encryption.impl;

import org.opensaml.core.xml.AbstractXMLObjectBuilder;
import org.opensaml.xmlsec.encryption.Salt;
import org.opensaml.xmlsec.encryption.XMLEncryptionBuilder;
import org.opensaml.xmlsec.encryption.support.EncryptionConstants;

/**
 * Builder of {@link org.opensaml.xmlsec.encryption.EncryptionMethod}.
 */
public class SaltBuilder extends AbstractXMLObjectBuilder<Salt> implements
        XMLEncryptionBuilder<Salt> {

    /**
     * Constructor.
     * 
     */
    public SaltBuilder() {
    }

    /** {@inheritDoc} */
    public Salt buildObject(final String namespaceURI, final String localName,
            final String namespacePrefix) {
        return new SaltImpl(namespaceURI, localName, namespacePrefix);
    }

    /** {@inheritDoc} */
    public Salt buildObject() {
        return buildObject(EncryptionConstants.XMLENC11_NS, Salt.DEFAULT_ELEMENT_LOCAL_NAME,
                EncryptionConstants.XMLENC11_PREFIX);
    }

}

==> opensaml-xmlsec-impl-5.1.1-sources.jar: org/opensaml/xmlsec/encryption/impl/SaltBuilder.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.xmlsec.encryption.impl;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

import org.opensaml.core.xml.AbstractXMLObjectBuilder;
import org.opensaml.xmlsec.encryption.Salt;
import org.opensaml.xmlsec.encryption.XMLEncryptionBuilder;
import org.opensaml.xmlsec.encryption.support.EncryptionConstants;

/**
 * Builder of {@link Salt}.
 */
public class SaltBuilder extends AbstractXMLObjectBuilder<Salt> implements
        XMLEncryptionBuilder<Salt> {

    /** {@inheritDoc} */
    @Nonnull public Salt buildObject(@Nullable final String namespaceURI, @Nonnull final String localName,
            @Nullable final String namespacePrefix) {
        return new SaltImpl(namespaceURI, localName, namespacePrefix);
    }

    /** {@inheritDoc} */
    @Nonnull public Salt buildObject() {
        return buildObject(EncryptionConstants.XMLENC11_NS, Salt.DEFAULT_ELEMENT_LOCAL_NAME,
                EncryptionConstants.XMLENC11_PREFIX);
    }

}
